@@ -1,6 +1,7 @@
 import datetime
 import random
 import time
+import sys
 
 from . import base36
 
@@ -29,4 +30,6 @@ def parseAidx(aidx) -> datetime.datetime:
     base36_time = aidx[:8]
     time_milliseconds = int(base36.b36decode(base36_time))
     timestamp = 946684800 + time_milliseconds / 1000
+    if sys.version_info < (3, 11): # Python3.11からdatetimee.UTCが追加されたため
+        return datetime.datetime.utcfromtimestamp(timestamp)
     return datetime.datetime.fromtimestamp(timestamp, datetime.UTC)
\ No newline at end of file
